==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.md <==
# AmazonSimpleStorageServiceS3IntelligentTiering


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')
```



| Illustration | AmazonSimpleStorageServiceS3IntelligentTiering | AmazonSimpleStorageServiceS3IntelligentTieringCard | AmazonSimpleStorageServiceS3IntelligentTieringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTiering](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.Local.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTieringCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTieringCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTieringGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTieringGroup.Local.png) |




## AmazonSimpleStorageServiceS3IntelligentTiering

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTiering
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTiering('AmazonSimpleStorageServiceS3IntelligentTiering', 'Amazon Simple Storage Service S3 Intelligent Tiering', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTiering
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTiering('AmazonSimpleStorageServiceS3IntelligentTiering', 'Amazon Simple Storage Service S3 Intelligent Tiering', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3IntelligentTieringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringCard('AmazonSimpleStorageServiceS3IntelligentTieringCard', 'Amazon Simple Storage Service S3 Intelligent Tiering Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringCard('AmazonSimpleStorageServiceS3IntelligentTieringCard', 'Amazon Simple Storage Service S3 Intelligent Tiering Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3IntelligentTieringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringGroup('AmazonSimpleStorageServiceS3IntelligentTieringGroup', 'Amazon Simple Storage Service S3 Intelligent Tiering Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringGroup('AmazonSimpleStorageServiceS3IntelligentTieringGroup', 'Amazon Simple Storage Service S3 Intelligent Tiering Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.md <==
# AmazonSimpleStorageServiceS3IntelligentTiering


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')
```



| Illustration | AmazonSimpleStorageServiceS3IntelligentTiering | AmazonSimpleStorageServiceS3IntelligentTieringCard | AmazonSimpleStorageServiceS3IntelligentTieringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTiering](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering.Local.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTieringCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTieringCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3IntelligentTieringGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTieringGroup.Local.png) |




## AmazonSimpleStorageServiceS3IntelligentTiering

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTiering
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTiering('AmazonSimpleStorageServiceS3IntelligentTiering', 'Amazon Simple Storage Service S3 Intelligent Tiering', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTiering
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTiering('AmazonSimpleStorageServiceS3IntelligentTiering', 'Amazon Simple Storage Service S3 Intelligent Tiering', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3IntelligentTieringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringCard('AmazonSimpleStorageServiceS3IntelligentTieringCard', 'Amazon Simple Storage Service S3 Intelligent Tiering Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringCard('AmazonSimpleStorageServiceS3IntelligentTieringCard', 'Amazon Simple Storage Service S3 Intelligent Tiering Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3IntelligentTieringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringGroup('AmazonSimpleStorageServiceS3IntelligentTieringGroup', 'Amazon Simple Storage Service S3 Intelligent Tiering Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3IntelligentTieringGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3IntelligentTiering')

' renders the element
AmazonSimpleStorageServiceS3IntelligentTieringGroup('AmazonSimpleStorageServiceS3IntelligentTieringGroup', 'Amazon Simple Storage Service S3 Intelligent Tiering Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
